Class: SparseImage::Mount

Inherits:
Object
  • Object
show all
Defined in:
lib/vagrant-sparseimage.rb

Instance Method Summary collapse

Constructor Details

#initialize(app, env) ⇒ Mount

Mount sparse images on the host machine and add them to the config for the guest Create the sparse image files if necessary.



183
184
185
186
# File 'lib/vagrant-sparseimage.rb', line 183

def initialize(app, env)
  @app = app
  @env = env
end

Instance Method Details

#call(env) ⇒ Object



188
189
190
191
192
# File 'lib/vagrant-sparseimage.rb', line 188

def call(env)
  vm = env[:machine]
  SparseImage::mount(vm)
  @app.call(env)
end